clear
set more off

*Load Data
cd ..

insheet using data.csv

gen b_year = 2019 - age

//Generational variable- Defi of Neil Howe and William Strauss 
		gen genr=.
		replace genr=1 if b_year >2000 //2000 to present : New Silent Generation or Generation Z 
		replace genr=2 if b_year >=1980 & b_year<=2000  // 1980 to 2000: Millennials or Generation Y
		replace genr=3 if b_year >=1965 & b_year<=1979 // 1965 to 1979: Thirteeners or Generation X
		replace genr=4 if b_year >=1946 & b_year<=1964  // 1946 to 1964: Baby Boomers
		replace genr=5 if b_year >=1925 & b_year<=1945 // 1925 to 1945: Silent Generation
		replace genr=6 if b_year >=1900 & b_year<=1924 // 1900 to 1924: G.I. Generation

label define genr 1 "New Silent Generation or Generation Z" 2 "Millennials or Generation Y" 3 "Thirteeners or Generation X" 4 "Baby Boomers" 5 "Silent Generation" 6 "G.I. Generation"
label values genr genr
	

//Demean
summarize age
generate demage = age - r(mean)

//Age in generation

forvalues i = 1/6 {
bys genr:egen maxyear`i'=max(b_year) if genr==`i'
				}
egen maxyear = rowmax(maxyear*)	
	
gen age_in_genr = (maxyear -b_year)
	
browse maxyear1 maxyear2 maxyear3 maxyear4 maxyear5 maxyear6 maxyear genr b_year age_in_genr


label variable gs1   "I have overcome setbacks to conquer an important challenge" 
label variable gs2   "New ideas and projects sometimes distract me from previous ones*" 
label variable gs3   "My interests change from year to year*" 
label variable gs4   "Setbacks don’t discourage me" 
label variable gs5   "I have been obsessed with a certain idea or project for a short time but later lost interest*" 
label variable gs6   "I am a hard worker" 
label variable gs7   "I often set a goal but later choose to pursue a different one*" 
label variable gs8   " I have difficulty maintaining my focus on projects that take more than a few months to complete*" 
label variable gs9   "I finish whatever I begin" 
label variable gs10   "I have achieved a goal that took years of work" 
label variable gs11   "I become interested in new pursuits every few months*" 
label variable gs12   "I am diligent" 
*Item was reverse scored.

//Grit scale is calculated as the average score for gs1-gs12
egen grit=rowmean(gs1-gs12 )

//TheConsistency of Interest subscale is calculated as the average score for items 2 5 7 8 11
egen ci=rowmean(gs2 gs5 gs7 gs8 gs11 )

//The Perseverance of Effort subscale is calculated as the average score for items 1, 4, 6, 9, 10 and 12
egen pe=rowmean(gs1 gs4 gs6 gs9 gs10 gs12 )



label define genderl 1 "Male" 2 "Female" 3 "Other" 
label values gender genderl
replace gender=. if gender==0


label define racel 1 "Asian" 2 "Arab" 3 "Black" 4 "Indigenous Australian, Native American or White"  5 "Other" 
label values race racel
replace race=. if race==0

label define educationl 1 "Less than high school" 2 "High school" 3 "University degree" 4 "Graduate degree"  
label values education educationl
replace education=. if education==0



log using table1.txt, replace text
sum grit age i.genr i.gender i.race i.education
log close


//Graphs

graph bar (count)  , over(genr) blabel(total, position(inside) format(%9.0f) color(white))  horizontal xsize(7)
graph export Figure1.pdf, replace

sum b_year
hist b_year, xtitle(birth year) name(Fig2a, replace)

sum age_in_genr
hist age_in_genr, xtitle(Age in Generation) bin(15) name(Fig2b, replace)
graph combine Fig2a Fig2b
graph export Figure2.pdf, replace

sum grit
hist grit, xtitle(Grit-O Scale)
graph export Figure3.pdf, replace



//Scale Construction
 alpha gs*, c
 alpha gs*, i c
 
drop if age ==228
drop if age ==350




// Add Country Fixed / Random Effects 
egen id = group(country)
xtset id

// Create individual Generation Categories for Comparison
tab genr

*Gen Z*
gen genz = 0
replace genz=1 if genr==1

*Gen Y*
gen geny = 0
replace geny=1 if genr==2

*Gen X*
gen genx = 0
replace genx=1 if genr==3

*Baby Boomers*
gen babyboom = 0
replace babyboom=1 if genr==4



*Cleaner Graphs*
grstyle init
grstyle set plain



*Overall Effect of Age on Grit excluding Generation*
xtreg grit i.gender i.race i.education c.age##c.age, fe robust
margins, at(age=(15(5)65))
marginsplot, title(Predicted Grit by Age) xtitle(Age) ytitle(Predicted Amount of Grit) name(Fig4a, replace)

*Overall Effect of Age in Generation on Grit*
xtreg grit i.gender i.race i.education i.genr if genr<5, fe robust
margins, at(genr=(1(1)4))
marginsplot, title(Predicted Grit by Age in Generation)   ///
xlabel(1 "Generation Z " 2 "Generation Y " 3 "Generation X " 4 "Baby Boomers", labsize(small)) ytitle(Predicted Amount of Grit) xtitle("") name(Fig4b, replace)

graph combine Fig4a Fig4b
graph export Figure4.pdf, replace


twoway (scatter grit age if genr==1) (scatter grit age if genr==2 ) (scatter grit age if genr==3) (scatter grit age if genr==4) ///
(lfit grit age if genr==1) (lfit grit age if genr==2) (lfit grit age if genr==3) (lfit grit age if genr==4), ///
ytitle(Grit) ///
legend(order(1 "Gen Z" 2 "Gen Y" 3 "Gen X" 4 "Baby Boomers")) 
graph export Figure5.pdf, replace


replace education=. if education==0
replace gender=. if gender==3 | gender==0
replace race=. if race==0

sum i.race
*Age and Controls*
eststo m1: xtreg grit i.gender i.race i.education c.age, fe robust
*Generation dummies and controls*
eststo m2: xtreg grit i.gender i.race i.education i.genr, fe robust
*Age in generation, generation dummies, and controls*
eststo m3: xtreg grit i.gender i.race i.education i.genr c.age_in_genr, fe robust
*Age and Age^2 and Controls*
eststo m4: xtreg grit i.gender i.race i.education c.age##c.age, fe robust
*Age in generation, generation dummies, and controls*
eststo m5: xtreg grit i.gender i.race i.education i.genr c.age_in_genr##c.age_in_genr, fe robust
esttab m1 m2 m3 m4 m5 using table3.rtf, p(3) replace compress title(Age and Generational Effects on Grit) label star(* 0.10 ** 0.05 *** 0.01)

